@@ -1,6 +1,6 @@
 see.Fcdf.tck<-function () 
 {
-require(tcltk) || stop("tcltk support is absent")
+
     if (!exists("slider.env")) 
     slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     nu1 <- 5
@@ -12,7 +12,7 @@ require(tcltk) || stop("tcltk support is absent")
     xmax <- 10
     assign("xmax", tclVar(xmax), envir = slider.env)
         
-    dev.new(height=4,width=8);par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))
+    dev.new(height=4,width=8);par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1.5,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))
     norm.refresh <- function(...) {
         nu1 <- as.numeric(evalq(tclvalue(nu1), envir = slider.env))
         nu2 <- as.numeric(evalq(tclvalue(nu2), envir = slider.env))
@@ -29,7 +29,7 @@ require(tcltk) || stop("tcltk support is absent")
             }
     tclServiceMode(TRUE)
     m <- tktoplevel()
-    tkwm.title(m, "Visualizing the F Distribution")
+    tkwm.title(m, "F(\u03bd\u2081, \u03bd\u2082)")
     tkpack(tklabel(m,text="      Visualizing the F Distribution      "))
     tkwm.geometry(m, "+0+0")
     tkpack(fr <- tkframe(m), side = "top")
@@ -64,7 +64,7 @@ require(tcltk) || stop("tcltk support is absent")
 
 see.F.tck<-function () 
 {
-require(tcltk) || stop("tcltk support is absent")
+
     if (!exists("slider.env"))
     slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     nu1 <- 5
@@ -90,7 +90,7 @@ require(tcltk) || stop("tcltk support is absent")
                     }
     tclServiceMode(TRUE)
     m <- tktoplevel()
-    tkwm.title(m, "Visualizing the F Distribution")
+    tkwm.title(m, "F(\u03bd\u2081, \u03bd\u2082)")
     tkpack(tklabel(m,text="      Visualizing the F Distribution      "))
     tkwm.geometry(m, "+0+0")
     tkpack(fr <- tkframe(m), side = "top")
