@@ -1,6 +1,6 @@
 see.logis.tck<-function () 
 {
-require(tcltk) || stop("tcltk support is absent")
+
     if (!exists("slider.env")) 
         slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     theta <- 1
@@ -26,7 +26,7 @@ require(tcltk) || stop("tcltk support is absent")
                     }
     tclServiceMode(TRUE)
     m <- tktoplevel()
-    tkwm.title(m, "Visualizing the Logistic Distribution")
+    tkwm.title(m, "LOGIS(\u03b2, \u03b8)")
     tkpack(tklabel(m,text="      Visualizing the Logistic Distribution      "))
     tkwm.geometry(m, "+0+0")
     tkpack(fr <- tkframe(m), side = "top")
@@ -64,7 +64,7 @@ require(tcltk) || stop("tcltk support is absent")
 
 
 see.logiscdf.tck<-function (){ 
-require(tcltk) || stop("tcltk support is absent")
+
     if (!exists("slider.env")) 
         slider.env <- NULL; suppressWarnings(rm(slider.env)); slider.env <<- new.env()# Dummy to trick R CMD check 
     theta <- 1
@@ -76,7 +76,7 @@ require(tcltk) || stop("tcltk support is absent")
     xmax <- 10
     assign("xmax", tclVar(xmax), envir= slider.env)
            
-    dev.new(height=4,width=8);par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))
+    dev.new(height=4,width=8);par(mar=c(4.4,4.5,1,0.5),cex=.85, oma = c(0,0,1.5,0)); layout(matrix(c(1,2), 1, 2, byrow = TRUE))
    norm.refresh <- function(...) {
         theta <- as.numeric(evalq(tclvalue(theta), envir= slider.env))
         beta <- as.numeric(evalq(tclvalue(beta), envir= slider.env))
@@ -93,7 +93,7 @@ require(tcltk) || stop("tcltk support is absent")
                     }
     tclServiceMode(TRUE)
     m <- tktoplevel()
-  tkwm.title(m, "Visualizing the Logistic Distribution")
+  tkwm.title(m, "LOGIS(\u03b2, \u03b8)")
     tkpack(tklabel(m,text="      Visualizing the Logistic Distribution      "))
     tkwm.geometry(m, "+0+0")
     tkpack(fr <- tkframe(m), side = "top")
